Instance

Trait Instance 

pub trait Instance: SealedInstance + 'static {
    type Interrupt: Interrupt;

    const BITS: TimerBits;

    // Required method
    fn regs() -> *mut ();
}
timer instance.

Required Associated Constants

const BITS: TimerBits

Amount of bits this timer has.

Required Associated Types

type Interrupt: Interrupt

Interrupt for this timer.

Required Methods

fn regs() -> *mut ()

Registers for this timer.

This is a raw pointer to the register block. The actual register block layout varies depending on the timer type.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl Instance for ATIM1

Source

const BITS: TimerBits = TimerBits::Bits32

Source

type Interrupt = ATIM1

Source

impl Instance for BTIM1

Source

const BITS: TimerBits = TimerBits::Bits32

Source

type Interrupt = BTIM1

Source

impl Instance for BTIM2

Source

const BITS: TimerBits = TimerBits::Bits32

Source

type Interrupt = BTIM2

Source

impl Instance for GPTIM1

Source

const BITS: TimerBits = TimerBits::Bits32

Source

type Interrupt = GPTIM1

Source

impl Instance for GPTIM2

Source

const BITS: TimerBits = TimerBits::Bits32

Source

type Interrupt = GPTIM2